@@ -1,7 +1,7 @@
 /*
  * (C) P.Horton 2004
  *
- * $Id: lib.h 153 2004-12-16 20:59:39Z pdh $
+ * $Id: lib.h 166 2005-03-22 20:55:41Z pdh $
  *
  * This code is covered by the GNU General Public License. For details see the file "COPYING".
  */
@@ -304,8 +304,9 @@ static inline void yield(void)
 #define LCD_MENU_ABORT						(-3)
 #define LCD_MENU_BAD_ARGS					(-4)
 
+extern void lcd_init(void);
 extern void lcd_line(int, const char *);
-extern int lcd_menu(const char **, unsigned, unsigned);
+extern int (*lcd_menu)(const char **, unsigned, unsigned);
 
 /* env.c */
 
@@ -313,6 +314,7 @@ extern int lcd_menu(const char **, unsigned, unsigned);
 #define VAR_NET								1
 #define VAR_DHCP								2
 #define VAR_INITRD							3
+#define VAR_NETCON							4
 
 extern int env_put(const char *, const char *, unsigned);
 extern const char *env_get(const char *, int);
@@ -332,6 +334,8 @@ extern int boot(int);
 #define NVFLAG_IDE_DISABLE_TIMING		(1 << 2)
 #define NVFLAG_IDE_ENABLE_SLAVE			(1 << 3)
 #define NVFLAG_CONSOLE_DISABLE			(1 << 4)
+#define NVFLAG_HORZ_MENU					(1 << 5)
+#define NVFLAG_CONSOLE_PCI_SERIAL		(1 << 7)
 
 #define NV_STORE_VERSION					2
 
@@ -352,6 +356,14 @@ extern struct nv_store nv_store;
 extern void nv_get(int);
 extern void nv_put(void);
 
+/* netcon.c */
+
+extern int netcon_poll(void);
+extern void netcon_disable(void);
+extern unsigned netcon_read(void *, unsigned);
+extern unsigned netcon_write(const void *, unsigned);
+extern int netcon_enabled(void);
+
 #endif
 
 /* vi:set ts=3 sw=3 cin path=include,../include: */
