@@ -1,7 +1,7 @@
 /*
  * (C) P.Horton 2004
  *
- * $Id: shell.c 137 2004-11-27 00:26:09Z pdh $
+ * $Id: shell.c 166 2005-03-22 20:55:41Z pdh $
  *
  * This code is covered by the GNU General Public License. For details see the file "COPYING".
  */
@@ -45,6 +45,7 @@ extern int cmnd_goto(int);
 extern int cmnd_onerror(int);
 extern int cmnd_exit(int);
 extern int cmnd_abort(int);
+extern int cmnd_netcon(int);
 
 static int cmnd_arguments(int);
 static int cmnd_help(int);
@@ -106,6 +107,7 @@ static struct
 	{ "select",			cmnd_menu,			0,					"title timeout option ...",							},
 	{ "noop",			cmnd_noop,			0,					"[arguments ...]",										},
 	{ "sleep",			cmnd_sleep,			0,					"sleep period",											},
+	{ "netcon",			cmnd_netcon,		0,					"[host [port [port]]]",									},
 
 #ifdef _DEBUG
 	{ "arguments",		cmnd_arguments,	0,					"[arguments ...]",										},
@@ -182,6 +184,7 @@ static int cmnd_nvflags(int opsz)
 		"IDE timing disabled",
 		"IDE slave enabled",
 		"Console disabled",
+		"Horizontal menus",
 	};
 	unsigned indx, mask;
 	unsigned long bit;
@@ -194,7 +197,7 @@ static int cmnd_nvflags(int opsz)
 		bit = evaluate(argv[indx], &ptr);
 		if(*ptr)
 			return E_BAD_EXPR;
-		if(bit > 31)
+		if(bit >= sizeof(nv_store.flags) * 8)
 			return E_BAD_VALUE;
 
 		mask |= 1 << bit;
@@ -205,8 +208,15 @@ static int cmnd_nvflags(int opsz)
 		nv_put();
 	}
 
-	for(indx = 0; indx < elements(msg); ++indx)
-		printf("%x: %c %s\n", indx, (nv_store.flags & (1 << indx)) ? '*' : '.', msg[indx]);
+	for(indx = 0; indx < sizeof(nv_store.flags) * 8; ++indx) {
+
+		mask = 1 << indx;
+
+		if(indx < elements(msg))
+			printf("%x: %c %s\n", indx, (nv_store.flags & mask) ? '*' : '.', msg[indx]);
+		else if(nv_store.flags & mask)
+			printf("%x: *\n", indx);
+	}
 
 	return E_NONE;
 }
