@@ -1,7 +1,7 @@
 /*
  * (C) P.Horton 2004
  *
- * $Id: tulip.c 141 2004-11-28 10:38:17Z pdh $
+ * $Id: tulip.c 175 2005-03-31 20:50:43Z pdh $
  *
  * This code is covered by the GNU General Public License. For details see the file "COPYING".
  */
@@ -546,16 +546,6 @@ void tulip_init(void)
 	nic_avail = tulip_setup(PCI_DEV_ETH0, PCI_FNC_ETH0, IO_BASE_ETH0);
 	tulip_setup(PCI_DEV_ETH1, PCI_FNC_ETH1, IO_BASE_ETH1);
 
-	/* without this Tulip bus mastering doesn't work correctly */
-
-		/* apparently early Galileos require the read *
-		 * before the write else they lock up. info   *
-		 * picked up from kernel source               */
-
-	BRDG_REG_WORD(BRDG_REG_TIMEOUT_RETRY);
-
-	BRDG_REG_WORD(BRDG_REG_TIMEOUT_RETRY) = 0xffff;
-
 	if(!nic_avail)
 		return;
 
